/*
	Pinguino and MOD-BT example
	Receive and recognise characters
			
	Olimex 2012
	https://www.olimex.com/Products

*/


/********** Libraries ***************/



/********** Macros & Constants ******/

	
	//For more info, refer to the schematics at 
	//https://www.olimex.com/Products
		
	#if ( defined(PIC32_PINGUINO_OTG) || defined(PIC32_PINGUINO) || defined(PIC32_PINGUINO_MICRO))

	//Definitions for 
	// -- PIC32-PINGUINO
	// -- PIC32-PINGUINO-OTG
	// -- PIC32-PINGUINO-MICRO
	
	#define btp UART2      //The UEXT is on UART2
	#define btbaud 9600
	
	//YELLOW LED is D1
	#define YLEDINIT   TRISDCLR = 0x02;
	#define YLED1      PORTDSET = 0x02;
	#define YLED0      PORTDCLR = 0x02;
	#define YLEDSWITCH PORTD   ^= 0x02;
	
	//GREEN LED is B15
	#define GLEDINIT  	TRISGCLR = 0x40;
	#define GLED1 		PORTGSET = 0x40;
	#define GLED0 		PORTGCLR = 0x40;
	#define GLEDSWITCH  PORTG   ^= 0x40;
		
#endif
		
	//A macro that waits for a key via CDC
	//Works with all pinguinos that support CDC
	//Syntax:
	//   WAIT;   //-> pauses the program and waits
				 //   until a key is pressed 
		
	/* WAIT Macro */
	#define WAIT wait_123()
	char ch123;
	
	void wait_123() __attribute ((noinline));
	
	void wait_123()
	{
	  ch123 = CDC.getKey();
	}
	/* END Wait Macro */



/********** Function Prototypes *********/
	
	void message(char * m);
	
	void message(char * m)
	   { CDC.println(m);}

	void local_init_bt(unsigned char uart_port, uint32_t baud_rate);


/********** Main Functions  *********/
	void setup()
	{
		
		YLEDINIT;
		GLEDINIT;
		YLED0;
		GLED0;
		
		WAIT;
		message("Press a key to init:");
		WAIT;

		local_init_bt(btp, btbaud);
		
		message("Initi...Done.");
		
		//Clear the buffer of the Serial Communication
		SerialFlush(btp);
		
		}
		
		
	void loop()
	{
		//reads every received character from the BT module
		//Also, the characters '1' and '2' toggle the two LEDS on the board
		
		char comm;
		
		//waits until a character is received and stores it
		comm = SerialGetKey(btp);
		
		//Uncomment the next row if you want the board to echo characters on the terminal
		CDC.printf("%c", comm);
		
	

	}
		
/********** Function bodies *********/

	void local_init_bt(unsigned char uart_port, uint32_t baud_rate)
	{
		//configure the board to open a serial connection to the MOD-BT module (via UEXT)
		SerialConfigure(uart_port, UART_ENABLE, UART_RX_TX_ENABLED,	baud_rate);
	
	}



